@@ -62,11 +62,6 @@ class Switchboard(QUiLoader, StyleSheet):
 		2. Instantiate the subclass and show the UI.
 			sb = MyProject_sb()
 			sb.ui.show()
-
-		3. Run the app, show the window, wait for input, then terminate program with the status code returned from app.
-			exit_code = sb.app.exec_()
-			if exit_code != -1:
-				sys.exit(exit_code)
 	"""
 	app = QtWidgets.QApplication.instance() or QtWidgets.QApplication(sys.argv) #return the existing QApplication object, or create a new one if none exists.
 
@@ -532,6 +527,9 @@ class Switchboard(QUiLoader, StyleSheet):
 		if not inspect.isclass(clss):
 			return None
 
+		ui_class = type(ui) # Check if the ui is a QtWidget derived class
+		assert issubclass(ui_class, QtWidgets.QWidget), f'# Error: {__file__} in setSlots\n#\tUI must be a QtWidget derived class, but got {ui_class}'
+
 		setattr(clss, 'get_switchboard_instance', lambda slots_inst: self) #set an attribute for the slots class that returns it's switchboard instance. ie. <Your_slots_class>.get_switchboard_instance()
 
 		try:
@@ -819,11 +817,13 @@ class Switchboard(QUiLoader, StyleSheet):
 			return self._currentUi
 
 		except AttributeError as error:
+
 			if len(self._loadedUi)==1: #if only one ui is loaded set that ui as current.
 				ui = self._loadedUi.pop()
 				self._loadedUi.add(ui)
 				self.setCurrentUi(ui)
 				return ui
+
 			elif self.ui_location.endswith('.ui'): #if the ui location is set to a single ui, then load and set that ui as current.
 				ui = self.loadUi(self.ui_location)
 				self.setCurrentUi(ui)
@@ -1714,25 +1714,35 @@ class Switchboard(QUiLoader, StyleSheet):
 # --------------------------------------------------------------------------------------------
 
 if __name__=='__main__':
+	class MyProject():
+	    ...
 
-	app = QtWidgets.QApplication.instance() or QtWidgets.QApplication(sys.argv) #return the existing QApplication object, or create a new one if none exists.
+	class MySlots(MyProject):
+	    def __init__(self):
+	        self.sb = self.get_switchboard_instance()
 
-	from uitk.slots.example import Example
-	sb = Switchboard(slots_location=Example) #set relative paths, and explicity set the slots class instead of providing a path like: slots='slots/maya', which in this case would produce the same result with just a little more overhead.
-	ui = sb.example #get the ui by it's name.
-	ui.show()
+	    def MyButtonsObjectName(self):
+	        print("Button clicked!")
 
-	print ('ui:'.ljust(25), sb.ui)
-	print ('ui name:'.ljust(25), sb.ui.name)
-	print ('connected state:'.ljust(25), ui.isConnected)
-	print ('slots:'.ljust(25), ui.slots)
-	print ('method tb000:'.ljust(25), ui.tb000.getSlot())
-	print ('widget from method tb000:'.ljust(25), sb.getWidgetFromMethod(ui.tb000.getSlot()))
-	# for w in ui.widgets: print ('child widget:'.ljust(25), (w.name or type(w).__name__).ljust(25), w.prefix.ljust(25), w.type.ljust(15), w.derivedType.ljust(15), id(w))
 
-	exit_code = app.exec_()
-	if exit_code != -1:
-		sys.exit(exit_code) # run app, show window, wait for input, then terminate program with a status code returned from app.
+	sb = Switchboard(slots_location=MySlots)
+	ui = sb.example
+
+	print ('ui:'.ljust(20), ui)
+	print ('ui name:'.ljust(20), ui.name)
+	print ('ui path:'.ljust(20), ui.path) #The directory path containing the UI file
+	print ('ui tags:'.ljust(20), ui.tags) #Any UI tags as a list
+	print ('ui level:'.ljust(20), ui.level) #The UI level
+	print ('is current ui:'.ljust(20), ui.isCurrentUi) #True if the UI is set as current
+	print ('is submenu:'.ljust(20), ui.isSubmenu) #True if the UI is a submenu
+	print ('is initialized:'.ljust(20), ui.isInitialized) #True after the UI is first shown
+	print ('is connected:'.ljust(20), ui.isConnected) #True if the UI is connected to its slots
+	print ('slots:'.ljust(20), ui.slots) #The associated slots class instance
+	print ('method:'.ljust(20), ui.MyButtonsObjectName.getSlot())
+	print ('widget from method:'.ljust(20), sb.getWidgetFromMethod(ui.MyButtonsObjectName.getSlot()))
+	for w in ui.widgets: print ('child widget:'.ljust(20), (w.name or type(w).__name__).ljust(20), w.prefix.ljust(20), w.type.ljust(15), w.derivedType.ljust(15), id(w)) #All the widgets of the UI
+
+	ui.show(app_exec=True)
 
 print (__name__) #module name
 # --------------------------------------------------------------------------------------------
